@@ -6,7 +6,7 @@ package Excel::Writer::XLSX::Package::XMLwriterSimple;
 #
 # Used in conjunction with Excel::Writer::XLSX.
 #
-# Copyright 2000-2011, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2012, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -20,7 +20,7 @@ use Exporter;
 use Carp;
 
 our @ISA     = qw(Exporter);
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 #
 # NOTE: this module is a light weight re-implementation of XML::Writer. See
@@ -281,7 +281,7 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
- MM-MMXI, John McNamara.
+ MM-MMXII, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
 
