@@ -7,7 +7,7 @@ package Excel::Writer::XLSX::Workbook;
 #
 # Used in conjunction with Excel::Writer::XLSX
 #
-# Copyright 2000-2011, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2012, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -32,7 +32,7 @@ use Excel::Writer::XLSX::Package::XMLwriter;
 use Excel::Writer::XLSX::Utility qw(xl_cell_to_rowcol xl_rowcol_to_cell);
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 
 ###############################################################################
@@ -112,6 +112,13 @@ sub new {
         $self->{_filehandle}  = $self->{_filename};
         $self->{_internal_fh} = 0;
     }
+    elsif ( $self->{_filename} eq '-' ) {
+
+        # Support special filename/filehandle '-' for backward compatibility.
+        binmode STDOUT;
+        $self->{_filehandle}  = \*STDOUT;
+        $self->{_internal_fh} = 0;
+    }
     else {
         my $fh = IO::File->new( $self->{_filename}, 'w' );
 
@@ -198,7 +205,14 @@ sub close {
     $self->{_fileclosed} = 1;
     $self->_store_workbook();
 
-    return CORE::close( $self->{_filehandle} ) if $self->{_internal_fh};
+    # Return the file close value.
+    if ( $self->{_internal_fh} ) {
+        return $self->{_filehandle}->close();
+    }
+    else {
+        # Return true and let users deal with their own filehandles.
+        return 1;
+    }
 }
 
 
@@ -2197,6 +2211,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
-© MM-MMXI, John McNamara.
+© MM-MMXII, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
